@@ -17,9 +17,9 @@ def get_pivot_params(event, steps_manager):
             and step.execution_data['destination_sheet_index'] == destination_sheet_index:
             return json.dumps({
                 'sheet_index': step.params['sheet_index'],
-                'pivot_rows': step.params['pivot_rows'],
-                'pivot_columns': step.params['pivot_columns'],
-                'values': step.params['values'],
+                'pivot_rows_column_ids': step.params['pivot_rows_column_ids'],
+                'pivot_columns_column_ids': step.params['pivot_columns_column_ids'],
+                'values_column_ids_map': step.params['values_column_ids_map'],
             })
     
     # Return nothing, if there is no pivot that meets this criteria
