@@ -24,18 +24,19 @@ def get_unique_value_counts(event, steps_manager):
         'values': unique_value_counts_percents_series.index,
         'percents': unique_value_counts_percents_series, 
         'counts': unique_value_counts_series
-        })
+    })
 
     unique_value_counts_df = pd.DataFrame(unique_value_counts_df)
 
-    try:
-        return json.dumps(df_to_json_dumpsable(
-            unique_value_counts_df, 
-            {'values': 'values', 'percents': 'percents', 'counts': 'counts'},
-            False
-        ))
+    return json.dumps(df_to_json_dumpsable(
+        unique_value_counts_df, 
+        'value counts',
+        'imported',
+        {},
+        {},
+        {},
+        {'values': 'values', 'percents': 'percents', 'counts': 'counts'},
+        {'values': 'values', 'percents': 'percents', 'counts': 'counts'},
+        length_restriction=False
+    ))
 
-    except:
-        # As this is also a non-critical error, we don't want to display an error
-        # message in the case of failure, so we just return nothing
-        return ''
