@@ -64,9 +64,7 @@ def get_column_summary_graph(axis, df, axis_data_array):
         'param_filtered': filtered
     })
 
-    # Because the Column Summary Stat Graph is never zoomed in 
-    # we always return False as the second parameter
-    return fig, False
+    return fig
 
 def get_graph(event, steps_manager):
     """
@@ -112,26 +110,12 @@ def get_graph(event, steps_manager):
         # First, handle edge cases
         if not x_axis and not y_axis:
             # If no axes provided, return
-            log(f'failed_generate_graph', {
-                'params_graph_type': graph_type,
-                'params_failed_reason': 'no axis data'
-            })
-
             return ''
         if sheet_index is None or graph_type is None:
             # If no sheet_index or graph type is provided, return
-            failed_reason = 'no selected_sheet_index' if sheet_index is None else 'no graph_type'
-            log(f'failed_generate_graph', {
-                'params_graph_type': graph_type,
-                'params_failed_reason': failed_reason
-            })
             return ''
         if x_axis and len(x_axis_column_headers) > 1 and y_axis and len(y_axis_column_headers) > 1:
             # If both axises have more than 1 series, return
-            log(f'failed_generate_graph', {
-                'params_graph_type': graph_type,
-                'params_failed_reason': 'both axises have multiple columns'
-            })
             return ''
 
         # Create a copy of the dataframe, just for safety.
@@ -140,36 +124,36 @@ def get_graph(event, steps_manager):
 
         # Handle the graphs in alphabetical order
         if graph_type == BAR:
-            fig, is_zoomed = get_bar_chart(df, x_axis_column_headers, y_axis_column_headers)
+            fig = get_bar_chart(df, x_axis_column_headers, y_axis_column_headers)
             generation_code = get_bar_code(df, x_axis_column_headers, y_axis_column_headers, df_name)
         elif graph_type == BOX:
             # Box plots are only defined on one axis. The UI should enforce that 
             # it is never the case that a box plot is selected with series for both 
             # the x and y axis. However, if it does happen, we default to taking the x axis. 
             if x_axis:
-                fig, is_zoomed = get_box_plot(X, df, x_axis_column_headers)
+                fig = get_box_plot(X, df, x_axis_column_headers)
                 generation_code = get_box_code(X, df, x_axis_column_headers, df_name)
             else:
-                fig, is_zoomed = get_box_plot(Y, df, y_axis_column_headers)
+                fig = get_box_plot(Y, df, y_axis_column_headers)
                 generation_code = get_box_code(Y, df, y_axis_column_headers, df_name)
         elif graph_type == HISTOGRAM:
             # Histograms are only defined on one axis. The UI should enforce that 
             # it is never the case that a histogram is selected with series for both 
             # the x and y axis. However, if it does happen, we default to taking the x axis. 
             if x_axis:
-                fig, is_zoomed = get_histogram(X, df, x_axis_column_headers)
+                fig = get_histogram(X, df, x_axis_column_headers)
                 generation_code = get_histogram_code(X, df, x_axis_column_headers, df_name)
             else:
-                fig, is_zoomed = get_histogram(Y, df, y_axis_column_headers)
+                fig = get_histogram(Y, df, y_axis_column_headers)
                 generation_code = get_histogram_code(Y, df, y_axis_column_headers, df_name)
         elif graph_type == SCATTER:
-            fig, is_zoomed = get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers)
+            fig = get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers)
             generation_code = get_scatter_code(df, x_axis_column_headers, y_axis_column_headers, df_name)
         elif graph_type == SUMMARY_STAT:
             # We handle summary stats separately from the histogram, for now, because 
             # we only let the user use a histogram with all numeric data, whereas the column
             # summary stats may not be all numeric data. 
-            fig, is_zoomed = get_column_summary_graph(X, df, x_axis_column_headers)
+            fig = get_column_summary_graph(X, df, x_axis_column_headers)
             generation_code = ''
             
         # 1) Get rid of some of the default white space
@@ -198,9 +182,6 @@ def get_graph(event, steps_manager):
             fig, height, width
         )
 
-        # Tell the frontend if the graph is zoomed in
-        return_object['is_zoomed'] = is_zoomed
-
         return_object['generation_code'] = generation_code
 
         return json.dumps(return_object),
