@@ -132,89 +132,6 @@ def get_graph_labels(x_axis_column_headers, y_axis_column_headers):
 
     return x_axis_title, y_axis_title
 
-def get_starting_ranges(graph_type, df, x_axis_column_headers, y_axis_column_headers):
-    """
-    Helper function for determing range that the axis should default to on 
-    inital render. It finds the smallest value in the key series and sets the range of it
-    [smallest value in series, smallest value in series + STARTING_RANGE_RANGE]
-
-    It returns the object {
-        X: [start of range, end of range] or [None, None]
-        Y: [start of range, end of range] or [None, None]
-    }
-
-    At least one of the axises will be [None, None]
-    
-    In the following conditions, this function will return a range of [None, None] so 
-    as to not overwrite the plotly default:
-    1. the graph type is not a scatter plot or a bar chart.
-    2. the key series is not a NUMBER_SERIES.
-    3. the range of the key series is already less than STARTING_RANGE_RANGE.
-
-    This approach is used to avoid graphs rendering where the data is nearly invisible due to the 
-    range of the key axis being so large
-    """
-    if (graph_type != SCATTER and graph_type != BAR) or (x_axis_column_headers == [] and y_axis_column_headers == []):
-        # We only need to overwrite the default range in scatter plots and bar charts. 
-        # We also don't care about the case where the graph has no data.
-        return {
-            X: [None, None],
-            Y: [None, None]
-        } 
-
-    elif len(x_axis_column_headers) == 0 and len(y_axis_column_headers) > 0:
-        key_axis = Y
-        # Since the user has no way of zooming in/out the y axis, we regretably 
-        # don't start the graph zoomed in because they will be stuck there!
-        return {
-            X: [None, None],
-            Y: [None, None]
-        } 
-
-    elif len(x_axis_column_headers) > 0 and len(y_axis_column_headers) == 0:
-        # In this case the x axis is the key axis and it is the index series. 
-        # Because the index series is always a number, we don't have to do the 
-        # mito_type_check and we just make sure that there are more than 
-        # DEFAULT_RANGE rows. 
-        key_axis = X
-        return {
-            X: [0, STARTING_RANGE_MAX_RANGE] if len(df) > STARTING_RANGE_MAX_RANGE else [None, None],
-            Y: [None, None]
-        }
-
-    else: 
-        key_axis = X if len(x_axis_column_headers) == 1 else Y
-        key_series = df[x_axis_column_headers[0]] if key_axis == X else df[y_axis_column_headers[0]]
-
-        # If the series is not a number series, we give up on creating
-        # a heuristic for setting the x axis 
-        # TODO: Figure out if we can set the range as a list of the first 500 unique values
-        # Think about whether the order of the unique values in the chart matters. 
-        if get_mito_type(key_series) != NUMBER_SERIES:
-            return {
-                X: [None, None],
-                Y: [None, None]
-            } 
-
-        # Learn about the range of the key series to make decision
-        # about how we should set the default range of the graph
-        min_value_in_series = key_series.min()
-        max_value_in_series = key_series.max()
-
-        if max_value_in_series - min_value_in_series > STARTING_RANGE_MAX_RANGE:
-            # If the range of the series is greater than STARTING_RANGE_RANGE, then 
-            # set the starting range from the min_value_in_series to min_value_in_series + STARTING_RANGE_RANGE
-            return {
-                X: [min_value_in_series, min_value_in_series + STARTING_RANGE_MAX_RANGE] if key_axis == X else [None, None],
-                Y: [None, None] # the Y axis is never set zoomed in because the user has no way of zooming out
-            }
-        else:
-            # If the range of the series is less than STARTING_RANGE_RANGE, 
-            # don't overwrite plotly's default range
-            return {
-                X: [None, None],
-                Y: [None, None]
-            } 
 
 def filter_df_to_top_unique_values_in_series(
         df: pd.DataFrame,
