@@ -6,7 +6,9 @@
 """
 Main file containing the mito widget.
 """
-from mitosheet.user.schemas import UJ_FEEDBACKS, UJ_MITOSHEET_LAST_FIFTY_USAGES
+import json
+from mitosheet.saved_analyses.save_utils import read_saved_analysis_names
+from mitosheet.user.schemas import UJ_FEEDBACKS, UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_TOURS, UJ_USER_EMAIL
 from mitosheet.user.db import get_user_field
 from mitosheet.utils import get_new_id
 from mitosheet.api import API
@@ -17,7 +19,7 @@ from ipywidgets import DOMWidget
 import traitlets as t
 
 from mitosheet._frontend import module_name, module_version
-from mitosheet.errors import EditError, get_recent_traceback, get_recent_traceback_as_list
+from mitosheet.errors import MitoError, get_recent_traceback, get_recent_traceback_as_list
 from mitosheet.saved_analyses import (
     read_and_upgrade_analysis, 
     write_analysis,
@@ -42,28 +44,10 @@ class MitoWidget(DOMWidget):
     _view_module = t.Unicode(module_name).tag(sync=True)
     _view_module_version = t.Unicode(module_version).tag(sync=True)
 
-    is_local_deployment = t.Bool(True).tag(sync=True)
-    analysis_name = t.Unicode('').tag(sync=True)
-    curr_step_idx = t.Int(0).tag(sync=True)
-    sheet_json = t.Unicode('').tag(sync=True)
-    code_json = t.Unicode('').tag(sync=True)
-    df_names_json = t.Unicode('').tag(sync=True)
-    df_sources_json = t.Unicode('').tag(sync=True)
-    df_shape_json = t.Unicode('').tag(sync=True)
-    saved_analysis_names_json = t.Unicode('').tag(sync=True)
-    column_ids_array_json = t.Unicode('').tag(sync=True)
-    column_spreadsheet_code_json = t.Unicode('').tag(sync=True)
-    column_filters_json = t.Unicode('').tag(sync=True)
-    column_type_json = t.Unicode('').tag(sync=True)
-    has_rendered = t.Bool(True).tag(sync=True)
-    user_email = t.Unicode('').tag(sync=True)
-    step_summaries_list_json = t.Unicode('').tag(sync=True)
-    should_upgrade_mitosheet = t.Bool(False).tag(sync=True)
-    data_type_in_mito = t.Unicode('').tag(sync=True)
-    received_tours = t.Unicode('').tag(sync=True)
-    num_feedbacks = t.Int(0).tag(sync=True)
-    num_usages = t.Int(0).tag(sync=True)
-
+    sheet_data_json = t.Unicode('').tag(sync=True)
+    analysis_data_json = t.Unicode('').tag(sync=True)
+    user_profile_json = t.Unicode('').tag(sync=True)
+    
     def __init__(self, *args):
         """
         Takes a list of dataframes and strings that are paths to CSV files
@@ -71,12 +55,6 @@ class MitoWidget(DOMWidget):
         """
         # Call the DOMWidget constructor to set up the widget properly
         super(MitoWidget, self).__init__()
-
-        # Set if this is a local deployment
-        self.is_local_deployment = is_local_deployment()
-
-        # Mark if it is time for the user to update
-        self.should_upgrade_mitosheet = should_upgrade_mitosheet()
             
         # Set up the state container to hold private widget state
         self.steps_manager = StepsManager(args)
@@ -86,20 +64,27 @@ class MitoWidget(DOMWidget):
         # when we are rendering for the first time vs. refreshing the sheet
         self.has_rendered = False
 
-        # Set up starting shared state variables
-        self.update_shared_state_variables()
-
         # Set up message handler
         self.on_msg(self.receive_message)
 
         # And the api
         self.api = API(self.steps_manager, self.send)
 
-        # We also update the variables that mark how many times
-        # the user has given feedback, as well as how many times
-        # the user has used the tool
+        # We store static variables to make writing the shared
+        # state variables quicker; we store them so we don't 
+        # have to recompute them on each update
         self.num_feedbacks = len(get_user_field(UJ_FEEDBACKS))
         self.num_usages = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
+        self.is_local_deployment = is_local_deployment()
+        self.should_upgrade_mitosheet = should_upgrade_mitosheet()
+        self.received_tours = get_user_field(UJ_RECEIVED_TOURS)
+
+        # Set up starting shared state variables
+        self.update_shared_state_variables()
+
+    @property
+    def analysis_name(self):
+        return self.steps_manager.analysis_name
 
 
     def update_shared_state_variables(self):
@@ -107,22 +92,20 @@ class MitoWidget(DOMWidget):
         Helper function for updating all the variables that are shared
         between the backend and the frontend through trailets.
         """
-        self.sheet_json = self.steps_manager.sheet_json
-        self.curr_step_idx = self.steps_manager.curr_step_idx
-        self.column_ids_array_json = self.steps_manager.column_ids_array_json
-        self.column_spreadsheet_code_json = self.steps_manager.column_spreadsheet_code_json
-        self.code_json = self.steps_manager.code_json
-        self.df_names_json = self.steps_manager.df_names_json
-        self.df_sources_json = self.steps_manager.df_sources_json
-        self.df_shape_json = self.steps_manager.df_shape_json
-        self.analysis_name = self.steps_manager.analysis_name
-        self.saved_analysis_names_json = saved_analysis_names_json()
-        self.column_filters_json = self.steps_manager.column_filters_json
-        self.column_type_json = self.steps_manager.column_type_json
-        self.user_email = self.steps_manager.user_email
-        self.step_summaries_list_json = self.steps_manager.step_summaries_list_json
-        self.data_type_in_mito = str(self.steps_manager.data_type_in_mito)
-        self.received_tours = self.steps_manager.received_tours
+        self.sheet_data_json = self.steps_manager.sheet_data_json
+        self.analysis_data_json = self.steps_manager.analysis_data_json
+        self.user_profile_json = json.dumps({
+            # Dynamic, update each time
+            'userEmail': get_user_field(UJ_USER_EMAIL),
+            'receivedTours': get_user_field(UJ_RECEIVED_TOURS),
+            'savedAnalysisNames': read_saved_analysis_names(),
+            # Static over a single analysis
+            'hasRendered': self.has_rendered,
+            'isLocalDeployment': self.is_local_deployment,
+            'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
+            'numFeedbacks': self.num_feedbacks,
+            'numUsages': self.num_usages,
+        })
 
 
     def handle_edit_event(self, event):
@@ -216,21 +199,33 @@ class MitoWidget(DOMWidget):
             log_event_processed(event, self.steps_manager)
 
             return True
-        except EditError as e:
+        except MitoError as e:
             print(get_recent_traceback())
             print(e)
             
             # Log processing this event failed
             log_event_processed(event, self.steps_manager, failed=True, edit_error=e)
 
-            # Report it to the user, and then return
-            self.send({
+            # If the error says to ignore the error modal, then we
+            # send some data with the response so that the frontend
+            # knows to ignore the error moda 
+            response = {
                 'event': 'edit_error',
                 'id': event['id'],
                 'type': e.type_,
                 'header': e.header,
                 'to_fix': e.to_fix
-            })
+            }
+            if not e.error_modal:
+                response['data'] = {
+                    'event': 'edit_error',
+                    'type': e.type_,
+                    'header': e.header,
+                    'to_fix': e.to_fix
+                }
+
+            # Report it to the user, and then return
+            self.send(response)
         except:
             print(get_recent_traceback())
             # We log that processing failed, but have no edit error
@@ -247,7 +242,10 @@ class MitoWidget(DOMWidget):
         return False
 
 def sheet(
-        *args, 
+        *args,
+        view_df=False # We use this param to log if the mitosheet.sheet call is created from the df output button
+        # NOTE: if you add named variables to this function, make sure argument parsing on the front-end still
+        # works by updating the getArgsFromCellContent function.
     ) -> MitoWidget:
     """
     Renders a Mito sheet. If no arguments are passed, renders an empty sheet. Otherwise, renders
@@ -268,6 +266,7 @@ def sheet(
     """
     args = list(args)
 
+
     try:
         # We pass in the dataframes directly to the widget
         widget = MitoWidget(*args) 
@@ -294,6 +293,7 @@ def sheet(
                 'params_num_str_args': len([arg for arg in args if isinstance(arg, str)]),
                 'params_num_df_args': len([arg for arg in args if isinstance(arg, pd.DataFrame)]),
                 'params_df_index_type': [str(type(arg.index)) for arg in args if isinstance(arg, pd.DataFrame)],
+                'params_view_df': view_df
             }
         )
     )
