@@ -1,10 +1,5 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
 import os
-from mitosheet.telemetry.telemetry_utils import log
+from mitosheet.mito_analytics import log
 
 IPYTHON_STARTUP_FOLDER = os.path.join(os.path.expanduser("~"), '.ipython', 'profile_default', 'startup')
 IMPORT_MITOSHEET_FILE_PATH = os.path.join(IPYTHON_STARTUP_FOLDER, 'import_mitosheet.py')
@@ -22,12 +17,12 @@ try:
 \tdef add_mito_button_to_df_output(obj):
 \t\tbutton_uuid = uuid.uuid4()
 \t\ttry:
-\t\t\tmax_rows = pd.get_option('display.min_rows') # NOTE: this is due to https://github.com/pandas-dev/pandas/issues/44304
+\t\t\tmax_rows = pd.get_option('display.max_rows')
 \t\t\tmax_cols = pd.get_option('display.max_columns')
 \t\texcept:
 \t\t\tmax_rows = 10
 \t\t\tmax_cols = 20
-\t\treturn f'<div><div id={button_uuid} style="display:none; background-color:#9D6CFF; color:white; width:200px; height:30px; padding-left:5px; border-radius:4px; flex-direction:row; justify-content:space-around; align-items:center;" onmouseover="this.style.backgroundColor=\\'#BA9BF8\\'" onmouseout="this.style.backgroundColor=\\'#9D6CFF\\'" onclick="window.commands?.execute(\\'create-mitosheet-from-dataframe-output\\');">See Full Dataframe in Mito</div> <script> if (window.commands?.hasCommand(\\'create-mitosheet-from-dataframe-output\\')) document.getElementById(\\'{button_uuid}\\').style.display = \\'flex\\' </script> {obj.to_html(max_rows=max_rows, max_cols=max_cols)}</div>'
+\t\treturn f'<div><div id={button_uuid} style="display:none; background-color:#9D6CFF; color:white; width:200px; height:30px; padding-left:5px; border-radius:4px; flex-direction:row; justify-content:space-around; align-items:center;" onmouseover="this.style.backgroundColor=\\'#BA9BF8\\'" onmouseout="this.style.backgroundColor=\\'#9D6CFF\\'" onclick="window.commands?.execute(\\'create-mitosheet-from-dataframe-output\\');">See Full Dataframe in Mito</div> <script> if (window.commands.hasCommand(\\'create-mitosheet-from-dataframe-output\\')) document.getElementById(\\'{button_uuid}\\').style.display = \\'flex\\' </script> {obj.to_html(max_rows=max_rows, max_cols=max_cols)}</div>'
 
 \thtml_formatter = get_ipython().display_formatter.formatters['text/html']
 \thtml_formatter.for_type(pd.DataFrame, add_mito_button_to_df_output)
@@ -35,7 +30,7 @@ except:
 \tprint('Unable to automatically import mitosheet')
 """
 
-def create_startup_file() -> None:
+def create_startup_file():
     """
     Adds a file import_mitosheet.py to the user's IPython startup folder 
     so that Mito is automatically imported everytime they start an IPython kernel. 
@@ -56,7 +51,7 @@ def create_startup_file() -> None:
     log('created_df_button_startup_file')
 
 
-def remove_startup_file() -> None:
+def remove_startup_file():
     """
     Removes the import_mitosheet.py from the user's IPython startup folder
     so that the View in Mito button is not automatically displayed in 
