@@ -10,6 +10,7 @@ from typing import List
 import pandas as pd
 
 from mitosheet.sheet_functions.types.utils import get_mito_type
+from mitosheet.column_headers import ColumnIDMap
 
 # Constants for where the dataframe in the state came from
 DATAFRAME_SOURCE_PASSED = 'passed' # passed in mitosheet.sheet
@@ -34,6 +35,7 @@ class State():
             dfs: List[pd.DataFrame], 
             df_names: List[str]=None,
             df_sources: List[str]=None,
+            column_ids: ColumnIDMap=None,
             column_metatype=None,
             column_type=None,
             column_spreadsheet_code=None,
@@ -57,19 +59,46 @@ class State():
         # call
         self.df_sources = df_sources if df_sources is not None else [DATAFRAME_SOURCE_PASSED for _ in dfs]
 
+        # We then make a column id map if we do not already have one, so that we can identify each
+        # of the columns from their static ids through the rest of the analysis. 
+        # NOTE: every state variable below that is defined per column is access by _ids_ not
+        # by column headers. The column headers _only_ index into the dataframe itself
+        self.column_ids = column_ids if column_ids else ColumnIDMap(dfs)
+
         # The column_metatype is if it stores formulas or values
-        self.column_metatype = column_metatype if column_metatype is not None else [{key: 'value' for key in df.keys()} for df in dfs]
+        self.column_metatype = column_metatype if column_metatype is not None else [
+            {column_id: 'value' for column_id in self.column_ids.get_column_ids(sheet_index)} 
+            for sheet_index in range(len(dfs))
+        ]
 
         # The column_type is the type of the series in this column 
-        self.column_type = column_type if column_type is not None else [{key: get_mito_type(df[key]) for key in df.keys()} for df in dfs]
+        self.column_type = column_type if column_type is not None else [
+            {
+                column_id: get_mito_type(df[column_header]) 
+                for column_id, column_header, in self.column_ids.get_column_ids_map(sheet_index).items()
+            }
+            for sheet_index, df in enumerate(dfs)
+        ]
 
         # We make column_spreadsheet_code an ordered dictonary to preserve the order the formulas
         # are inserted, which in turn makes sure when we save + rerun an analysis, it's recreated
         # in the correct order (and thus the column order is preserved).
-        self.column_spreadsheet_code = column_spreadsheet_code if column_spreadsheet_code is not None else [OrderedDict({key: '' for key in df.keys()}) for df in dfs]
-        self.column_python_code = column_python_code if column_python_code is not None else [{key: '' for key in df.keys()} for df in dfs]
-        self.column_evaluation_graph = column_evaluation_graph if column_evaluation_graph is not None else [{key: set() for key in df.keys()} for df in dfs]
-        self.column_filters = column_filters if column_filters is not None else [{key: {'operator': 'And', 'filters': []} for key in df.keys()} for df in dfs]
+        self.column_spreadsheet_code = column_spreadsheet_code if column_spreadsheet_code is not None else [
+            {column_id: '' for column_id in self.column_ids.get_column_ids(sheet_index)} 
+            for sheet_index in range(len(dfs))
+        ]
+        self.column_python_code = column_python_code if column_python_code is not None else [
+            {column_id: '' for column_id in self.column_ids.get_column_ids(sheet_index)} 
+            for sheet_index in range(len(dfs))
+        ]
+        self.column_evaluation_graph = column_evaluation_graph if column_evaluation_graph is not None else [
+            {column_id: set() for column_id in self.column_ids.get_column_ids(sheet_index)} 
+            for sheet_index in range(len(dfs))
+        ]
+        self.column_filters = column_filters if column_filters is not None else [
+            {column_id: {'operator': 'And', 'filters': []} for column_id in self.column_ids.get_column_ids(sheet_index)} 
+            for sheet_index in range(len(dfs))
+        ]
 
     
     def __copy__(self):
@@ -81,6 +110,7 @@ class State():
             [df.copy(deep=False) for df in self.dfs],
             df_names=deepcopy(self.df_names),
             df_sources=deepcopy(self.df_sources),
+            column_ids=deepcopy(self.column_ids),
             column_metatype=deepcopy(self.column_metatype),
             column_type=deepcopy(self.column_type),
             column_spreadsheet_code=deepcopy(self.column_spreadsheet_code),
@@ -99,6 +129,7 @@ class State():
             [df.copy(deep=True) for df in self.dfs],
             df_names=deepcopy(self.df_names),
             df_sources=deepcopy(self.df_sources),
+            column_ids=deepcopy(self.column_ids),
             column_metatype=deepcopy(self.column_metatype),
             column_type=deepcopy(self.column_type),
             column_spreadsheet_code=deepcopy(self.column_spreadsheet_code),
@@ -112,7 +143,8 @@ class State():
             new_df: pd.DataFrame, 
             df_source: str, 
             sheet_index=None,
-            df_name=None
+            df_name=None,
+            use_deprecated_id_algorithm: bool=False
         ):
         """
         Helper function for adding a new dataframe to this state,
@@ -133,15 +165,17 @@ class State():
 
             # Save the source of this dataframe
             self.df_sources.append(df_source)
-            
+
+            # Add this to the column_ids map
+            column_ids = self.column_ids.add_df(new_df, use_deprecated_id_algorithm=use_deprecated_id_algorithm)
+
             # Update all the variables that depend on column_headers
-            column_headers = new_df.keys()
-            self.column_metatype.append({column_header: 'value' for column_header in column_headers})
-            self.column_type.append({column_header: get_mito_type(new_df[column_header]) for column_header in column_headers})
-            self.column_spreadsheet_code.append({column_header: '' for column_header in column_headers})
-            self.column_python_code.append({column_header: '' for column_header in column_headers})
-            self.column_evaluation_graph.append({column_header: set() for column_header in column_headers})
-            self.column_filters.append({column_header: {'operator':'And', 'filters': []} for column_header in column_headers})
+            self.column_metatype.append({column_id: 'value' for column_id in column_ids})
+            self.column_type.append({column_id: get_mito_type(new_df[column_header]) for column_id, column_header in column_ids.items()})
+            self.column_spreadsheet_code.append({column_id: '' for column_id in column_ids})
+            self.column_python_code.append({column_id: '' for column_id in column_ids})
+            self.column_evaluation_graph.append({column_id: set() for column_id in column_ids})
+            self.column_filters.append({column_id: {'operator':'And', 'filters': []} for column_id in column_ids})
 
             # Return the index of this sheet
             return len(self.dfs) - 1
@@ -156,15 +190,17 @@ class State():
             # Save the source of this dataframe, if it is passed. Otherwise, don't change it
             if df_source is not None:
                 self.df_sources[sheet_index] = df_source
-            
+
+            # Add this to the column_ids map
+            column_ids = self.column_ids.add_df(new_df, sheet_index=sheet_index, use_deprecated_id_algorithm=use_deprecated_id_algorithm)
+
             # Update all the variables that depend on column_headers
-            column_headers = new_df.keys()
-            self.column_metatype[sheet_index] = {column_header: 'value' for column_header in column_headers}
-            self.column_type[sheet_index] = {column_header: get_mito_type(new_df[column_header]) for column_header in column_headers}
-            self.column_spreadsheet_code[sheet_index] = {column_header: '' for column_header in column_headers}
-            self.column_python_code[sheet_index] = {column_header: '' for column_header in column_headers}
-            self.column_evaluation_graph[sheet_index] = {column_header: set() for column_header in column_headers}
-            self.column_filters[sheet_index] = {column_header: {'operator':'And', 'filters': []} for column_header in column_headers}
+            self.column_metatype[sheet_index] = {column_id: 'value' for column_id in column_ids}
+            self.column_type[sheet_index] = {column_id: get_mito_type(new_df[column_header]) for column_id, column_header in column_ids.items()}
+            self.column_spreadsheet_code[sheet_index] = {column_id: '' for column_id in column_ids}
+            self.column_python_code[sheet_index] = {column_id: '' for column_id in column_ids}
+            self.column_evaluation_graph[sheet_index] = {column_id: set() for column_id in column_ids}
+            self.column_filters[sheet_index] = {column_id: {'operator':'And', 'filters': []} for column_id in column_ids}
 
             # Return the index of this sheet
             return sheet_index
@@ -175,4 +211,43 @@ class State():
         """
         return not (sheet_index < 0 or sheet_index >= len(self.dfs))
 
+    def move_to_deprecated_id_algorithm(self):
+        """
+        This helper function will move the entire state to the new IDs,
+        for backwards compatibility reasons. Namely, users who pass
+        dataframes to mito directly have a bulk_old_rename appended to 
+        the start of their analysis that calls this function. 
+
+        This moves the IDs to what they would have been if there was a 
+        preprocessing step that had run, that had performed renames on
+        the column headers before they were allowed into Mito. Brutal.
+        """
+        from mitosheet.step_performers.bulk_old_rename.deprecated_utils import make_valid_header
+
+        # Loop over all the attributes of this object
+        for key, value in self.__dict__.items():
+            # And for anything defined on columns, update it to the new id schema
+            if key.startswith('column') and key != 'column_ids':
+                new_value = [
+                    {
+                        make_valid_header(k): v for k, v in column_map.items()
+                    } 
+                    for column_map in value
+                ]
+                self.__setattr__(key, new_value)
+        
+        # Then, update the column_evaluation_graph to use the old format as well
+        new_column_evaluation_graph = [
+            {
+                column_id: {make_valid_header(cid) for cid in dependency_list}
+                for column_id, dependency_list in column_evaluation_graph_map.items()
+            }
+            for column_evaluation_graph_map in self.column_evaluation_graph
+        ]
+        
+        self.column_evaluation_graph = new_column_evaluation_graph
+        
+        # Then, update the column ids mapping object itself
+        self.column_ids.move_to_deprecated_id_format()
+
     
\ No newline at end of file
