@@ -70,6 +70,10 @@ class Step:
     def df_sources(self):
         return self.post_state.df_sources
 
+    @property
+    def column_ids(self):
+        return self.post_state.column_ids
+    
     @property
     def column_metatype(self):
         return self.post_state.column_metatype
@@ -125,7 +129,8 @@ class Step:
         post_state_and_execution_data = self.step_performer.execute(new_prev_state, **params)
 
         if post_state_and_execution_data is not None:
-            # 
+            # If we don't get anything new back, then we just make this
+            # step a no-op, and don't do anything
             (new_post_state, execution_data) = post_state_and_execution_data
         else:
             # Sometimes step execution returns None, which functionally means that 
@@ -158,7 +163,7 @@ class Step:
             # Check (1)
             if step.step_type == FilterStepPerformer.step_type() and self.step_type == FilterStepPerformer.step_type():
                 if step.params['sheet_index'] == self.params['sheet_index'] \
-                    and step.params['column_header'] == self.params['column_header']:
+                    and step.params['column_id'] == self.params['column_id']:
                    step_indexes_to_skip.add(step_index) 
             
             # Check (2)
@@ -173,7 +178,7 @@ class Step:
             if self.step_type == SetColumnFormulaStepPerformer.step_type():
                 if self.step_type == previous_step.step_type \
                     and self.params['sheet_index'] == previous_step.params['sheet_index'] \
-                    and self.params['column_header'] == previous_step.params['column_header']:
+                    and self.params['column_id'] == previous_step.params['column_id']:
                     step_indexes_to_skip.add(len(all_steps_before_this_step) - 1)
 
         return step_indexes_to_skip
