@@ -1,9 +1,3 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-
 """
 NOTE: DO NOT CHANGE THIS FILE. THESE ARE DEPRECATED UTILS
 THAT CANNOT CHANGE AND SO SHOULD NEVER BE CHANGED.
@@ -11,7 +5,7 @@ THAT CANNOT CHANGE AND SO SHOULD NEVER BE CHANGED.
 
 import numbers
 import re
-from typing import Any, Callable, Dict, List
+from typing import Any, Dict, List
 from mitosheet.mito_analytics import log
 
 import pandas as pd
@@ -19,9 +13,7 @@ import pandas as pd
 import warnings
 import functools
 
-from mitosheet.types import ColumnHeader
-
-def deprecated(func: Callable) -> Callable:
+def deprecated(func):
     """
     This is a decorator which can be used to mark functions
     as deprecated. It will result in a warning being emitted
@@ -99,9 +91,9 @@ def make_valid_header(column_header: Any) -> str:
 make_valid_header_external = deprecated(make_valid_header)
 
 
-def is_valid_header(column_header: ColumnHeader) -> bool:
+def is_valid_header(column_header: Any) -> bool:
     """
-    A header is valid if it is a string that is made up of all word characters,
+    A header is valid if It is a string that is made up of all word characters,
     with at least one non numeric char, and has at least one char.
     Valid examples: A, ABC, 012B, 213_bac, 123_123
     Invalid examples: 123, 123!!!, ABC!, 123-123
@@ -116,7 +108,7 @@ def is_valid_header(column_header: ColumnHeader) -> bool:
     return isinstance(column_header, str) and \
         len(column_header) > 0 and \
         re.compile("^\w+$").search(column_header) and \
-        not column_header.isdigit() # type: ignore
+        not column_header.isdigit()
 
 def get_invalid_headers(df: pd.DataFrame) -> List[Any]:
     """
@@ -130,7 +122,7 @@ def get_invalid_headers(df: pd.DataFrame) -> List[Any]:
         if not is_valid_header(header)
     ]
 
-def get_header_renames(column_headers: List[ColumnHeader]) -> Dict[Any, str]:
+def get_header_renames(column_headers) -> Dict[Any, str]:
     """
     Given a list of column headers, returns a mapping from old, invalid headers to
     new, valid headers. Empty if no renames are necessary.
