@@ -5,13 +5,11 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import deepcopy
-from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.state import State
 from typing import Any, Dict, List, Optional
-from mitosheet.errors import (
-    make_no_sheet_error,
-    make_no_column_error,
-)
+
+from mitosheet.state import State
+from mitosheet.step_performers.step_performer import StepPerformer
+
 
 def get_valid_index(dfs, sheet_index, new_column_index):
     # make sure new_column_index is valid
@@ -32,7 +30,7 @@ class ReorderColumnStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 1
+        return 2
 
     @classmethod
     def step_type(cls) -> str:
@@ -55,18 +53,12 @@ class ReorderColumnStepPerformer(StepPerformer):
         cls,
         prev_state: State,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         new_column_index: int,
         **params
     ) -> State:
-        # if the sheet doesn't exist, throw an error
-        if not prev_state.does_sheet_index_exist_within_state(sheet_index):
-            raise make_no_sheet_error(sheet_index)
 
-        # We check that the column to be reordered exists
-        missing_column = set([column_header]).difference(prev_state.column_metatype[sheet_index].keys())
-        if len(missing_column) > 0:
-            raise make_no_column_error(missing_column)
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
 
         new_column_index = get_valid_index(prev_state.dfs, sheet_index, new_column_index)
             
@@ -89,9 +81,11 @@ class ReorderColumnStepPerformer(StepPerformer):
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         new_column_index: int
     ) -> List[str]:
+        column_header = prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
+
         new_column_index = get_valid_index(prev_state.dfs, sheet_index, new_column_index)
         df_name = post_state.df_names[sheet_index]
 
@@ -110,15 +104,15 @@ class ReorderColumnStepPerformer(StepPerformer):
     def describe(
         cls,
         sheet_index: int,
-        column_header: str,
+        column_id: str,
         new_column_index: int,
         df_names=None,
         **params
     ) -> str:
         if df_names is not None:
             df_name = df_names[sheet_index]
-            return f'Reordered {column_header} in {df_name}'
-        return f'Reordered {column_header}'
+            return f'Reordered {column_id} in {df_name}'
+        return f'Reordered {column_id}'
 
 
 def _execute_reorder_column(df, column_header, new_column_index):
@@ -127,4 +121,4 @@ def _execute_reorder_column(df, column_header, new_column_index):
     """
     df_columns = [col for col in df.columns if col != column_header]
     df_columns.insert(new_column_index, column_header)
-    return df[df_columns]
\ No newline at end of file
+    return df[df_columns]
