@@ -5,10 +5,12 @@
 # Distributed under the terms of the Modified BSD License.
 
 from copy import copy
-from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.state import DATAFRAME_SOURCE_DUPLICATED, State
 from typing import Any, Dict, List, Optional
 
+from mitosheet.state import DATAFRAME_SOURCE_DUPLICATED, State
+from mitosheet.step_performers.step_performer import StepPerformer
+from mitosheet.utils import get_first_unused_dataframe_name
+
 
 class DataframeDuplicateStepPerformer(StepPerformer):
     """
@@ -46,7 +48,7 @@ class DataframeDuplicateStepPerformer(StepPerformer):
 
         # Execute the step
         df_copy = post_state.dfs[sheet_index].copy(deep=True)
-        new_name = get_first_unused_name(post_state.df_names, post_state.df_names[sheet_index] + '_copy')
+        new_name = get_first_unused_dataframe_name(post_state.df_names, post_state.df_names[sheet_index] + '_copy')
         post_state.add_df_to_state(df_copy, DATAFRAME_SOURCE_DUPLICATED, df_name=new_name)
 
         return post_state, None
@@ -76,17 +78,3 @@ class DataframeDuplicateStepPerformer(StepPerformer):
             new_df_name = df_names[len(df_names) - 1]
             return f'Duplicated {old_df_name} to {new_df_name}'
         return f'Duplicated a df'
-
-
-def get_first_unused_name(df_names, dataframe_name):
-    """
-    Appends _1, _2, .. to df name until it finds an unused 
-    dataframe name. If no append is necessary, will just return
-    """
-    if dataframe_name not in df_names:
-        return dataframe_name
-
-    for i in range(len(df_names) + 1):
-        new_name = f'{dataframe_name}_{i + 1}'
-        if new_name not in df_names:
-            return new_name
\ No newline at end of file
