@@ -235,5 +235,5 @@ def test_upgrades_version_2_to_version_3():
 
 def test_main_cli_turn_off_logging():
     initialize_user()
-    out = subprocess.run(['python', '-m', 'mitosheet', 'turnofflogging'], capture_output=True)
+    subprocess.run(['python', '-m', 'mitosheet', 'turnofflogging'])
     assert get_user_field(UJ_MITOSHEET_TELEMETRY) == False
\ No newline at end of file
