@@ -1,14 +1,14 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 from copy import copy
-from typing import List
 
 
 REDO_EVENT = 'redo'
-REDO_PARAMS: List[str] = []
+REDO_PARAMS = []
 
 def execute_redo_update(steps_manager):
     steps_manager.execute_redo()
