@@ -8,19 +8,19 @@
 Saves the analysis with the passed name.
 """
 
-from mitosheet.save_utils import write_analysis
+from mitosheet.saved_analyses import write_analysis
 
 SAVE_ANALYSIS_UPDATE_EVENT = 'save_analysis_update'
 SAVE_ANALYSIS_UPDATE_PARAMS = ['analysis_name']
 
 def execute_save_analysis_update(
-        wsc,
+        steps_manager,
         analysis_name
     ):
     """
     Saves the analysis with the passed name
     """
-    write_analysis(wsc, analysis_name)
+    write_analysis(steps_manager, analysis_name)
 
 
 SAVE_ANALYSIS_UPDATE = {
